import {config} from "../config.js";

chrome.runtime.onInstalled.addListener((e) => {
    if (e.reason === "install") {
        setUninstallURL();
        handleOnInstall();
    }
});


/**
 * Perform one-time unsafe search.
 */
chrome.omnibox.onInputEntered.addListener((text) => {
    text = text.replace(config.omnibox + ' ', '');
    chrome.tabs.create({url: `${config.search}&p=${encodeURIComponent(text)}`});
});

/**
 * Opens a new tab with safe browsing information.
 */
chrome.browserAction.onClicked.addListener(() => {
    chrome.tabs.create({url: config.browserActionUrl});
});

/**
 * Setting uninstall URL.
 */
function setUninstallURL() {
    chrome.runtime.setUninstallURL(config.uninstall);
}


function handleOnInstall() {
    setTimeout(() => {
        chrome.tabs.query({url: '*://*.safetybrowsing.com/*'}, (tabs) => {
            if (tabs[0]) {
                chrome.tabs.executeScript(tabs[0].id, {
                    file: '/content_script/onInstallCallback.js'
                });
            }
        });
    }, 500);
}


